.. "MESSAGEix models" documentation master file, created by
   sphinx-quickstart on Tue Feb 23 14:52:14 2021.

MESSAGEix models
****************

:mod:`message_ix_models` provides tools for research using the MESSAGEix-GLOBIOM family of models.
These models are built in the `MESSAGEix framework <https://docs.messageix.org>`_ and on the `ix modeling platform (ixmp) <https://docs.messageix.org/ixmp/>`_.

.. toctree::
   :maxdepth: 1
   :caption: User guide

   install
   data
   cli

.. toctree::
   :maxdepth: 2
   :caption: API reference

   api/model
   api/project
   api/tools
   api/util
   api/testing

.. toctree::
   :maxdepth: 2
   :caption: Package data

   pkg-data/node
   pkg-data/codelists

.. toctree::
   :maxdepth: 2
   :caption: Development

   whatsnew
   migrate
   releasing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
